@@ -71,7 +71,8 @@ enum ELEM_TYPE {
   ELEM_TYPE_CHECKBOX,
   ELEM_TYPE_LIST_SINGLE,
   ELEM_TYPE_LIST_MULTI,
-  ELEM_TYPE_UPLOADFILE
+  ELEM_TYPE_UPLOADFILE,
+  ELEM_TYPE_DATE
 };
 enum ELEM_ID {
     ELEM_ID_ID = -1,
@@ -87,8 +88,14 @@ enum ELEM_ID {
 
 typedef struct _condition {
   int element_type_id;
+  int condition_type;
   char value[DEFAULT_LENGTH];
 } Condition;
+enum CONDITION_TYPE {
+    CONDITION_TYPE_NORMAL,
+    CONDITION_TYPE_DATE_FROM,
+    CONDITION_TYPE_DATE_TO
+};
 
 typedef struct _search_result {
   int hit_count;
