@@ -17,6 +17,7 @@ void search_actoin();
 void register_submit_action();
 void register_action();
 void ticket_action();
+void statistics_action();
 void help_action();
 void edit_top_action();
 void edit_top_submit_action();
@@ -26,8 +27,8 @@ void default_action();
 void output_header(Project*, char*, char*, int);
 void output_footer();
 int cgiMain();
-void output_form_element(List* element, ElementType* e_type);
-void output_form_element_4_condition(char*, ElementType*);
+void output_form_element(List*, ElementType*);
+void output_form_element_4_condition(ElementType*);
 int get_mode();
 static int contains(char* const, const char*);
 
@@ -53,6 +54,7 @@ void register_actions()
     register_action_actions("register", register_action);
     register_action_actions("register_submit", register_submit_action);
     register_action_actions("ticket", ticket_action);
+    register_action_actions("statistics", statistics_action);
     register_action_actions("reply", ticket_action);
     register_action_actions("help", help_action);
     register_action_actions("edit_top", edit_top_action);
@@ -70,6 +72,7 @@ enum NAVI {
     NAVI_SEARCH,
     NAVI_RSS,
     NAVI_HELP,
+    NAVI_STATISTICS,
     NAVI_MANAGEMENT
 };
 void output_header(Project* project, char* title, char* script_name, int navi)
@@ -83,7 +86,7 @@ void output_header(Project* project, char* title, char* script_name, int navi)
             "<head>\n"
             "\t<meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\" />\n"
             "\t<meta http-equiv=\"Content-Script-Type\" content=\"text/javascript\" />\n"
-            "\t<meta http-equiv=\"Content-Style-type\" content=\"text/css\" />"
+            "\t<meta http-equiv=\"Content-Style-type\" content=\"text/css\" />\n"
             "\t<title>Starbug1 %s - %s</title>\n", project->name, title);
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../css/style.css\" />\n", cgiScriptName);
     o(      "\t<link rel=\"stylesheet\" type=\"text/css\" href=\"%s/../css/user.css\" />\n", cgiScriptName);
@@ -97,13 +100,14 @@ void output_header(Project* project, char* title, char* script_name, int navi)
             "<h1 id=\"toptitle\" title=\"Starbug1\"><a href=\"http://sourceforge.jp/projects/starbug1/\"><img src=\"%s/../img/title.jpg\" alt=\"Starbug1\" /></a></h1>\n", cgiScriptName);
     o("<div>\n");
     o("<ul id='menu'>\n");
-    o("<li><a %s href='%s'>トップ</a></li>\n", navi == NAVI_TOP ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/list'>状態別チケット</a></li>\n", navi == NAVI_LIST ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/register'>チケット登録</a></li>\n", navi == NAVI_REGISTER ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/search'>チケット検索</a></li>\n", navi == NAVI_SEARCH ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/rss'>RSS Feed</a></li>\n", navi == NAVI_RSS ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/help'>ヘルプ</a></li>\n", navi == NAVI_HELP ? "class=\"current\"" : "", cgiScriptName);
-    o("<li><a %s href='%s/../admin.cgi'>管理ツール</a></li>\n", navi == NAVI_MANAGEMENT ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s' title=\"トップページへ移動します\">トップ</a></li>\n", navi == NAVI_TOP ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/list' title=\"状態別のチケット一覧を参照します\">状態別チケット</a></li>\n", navi == NAVI_LIST ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/register' title=\"新規にチケットを登録します\">チケット登録</a></li>\n", navi == NAVI_REGISTER ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/search' title=\"チケットを検索します\">チケット検索</a></li>\n", navi == NAVI_SEARCH ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/statistics' title=\"統計情報を表示します\">統計情報</a></li>\n", navi == NAVI_STATISTICS ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/rss' title=\"RSS Feed\">RSS Feed</a></li>\n", navi == NAVI_RSS ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/help' title=\"ヘルプを参照します\">ヘルプ</a></li>\n", navi == NAVI_HELP ? "class=\"current\"" : "", cgiScriptName);
+    o("<li><a %s href='%s/../admin.cgi' title=\"各種設定を行ないます\">管理ツール</a></li>\n", navi == NAVI_MANAGEMENT ? "class=\"current\"" : "", cgiScriptName);
     o("</ul>\n");
     o("<br clear='all' />\n");
     o("</div>\n");
@@ -228,18 +232,18 @@ void output_ticket_table_header(List* element_types)
     char* query_string = format_query_string_without_sort_and_page(query_string_buffer);
 
     o(      "\t<tr>\n");
-    o(      "\t\t<th><a href=\"%s/search?%ssort=-1&amp;%s\" title=\"クリックする度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o(      "\t\t<th><a href=\"%s/search?%ssort=-1&amp;%s\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">ID</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
     foreach (it, element_types) {
         ElementType* et = it->element;
         o("\t\t<th>\n");
-        o("\t\t\t<a href=\"%s/search?%ssort=%d&amp;%s\" title=\"クリックする度に昇順、降順で並べ替えを行ないます。\">", cgiScriptName, reverse ? "" : "r", et->id, query_string);
+        o("\t\t\t<a href=\"%s/search?%ssort=%d&amp;%s\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">", cgiScriptName, reverse ? "" : "r", et->id, query_string);
         h(et->name);
         o("</a>\n");
         o("\t\t</th>\n");
     }
-    o("\t\t<th><a href=\"%s/search?%ssort=-2&amp;%s\" title=\"クリックする度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s\" title=\"クリックする度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
-    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s\" title=\"クリックする度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th><a href=\"%s/search?%ssort=-2&amp;%s\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">投稿日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">最終更新日時</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
+    o("\t\t<th><a href=\"%s/search?%ssort=-3&amp;%s\" title=\"押す度に昇順、降順で並べ替えを行ないます。\">放置日数</a></th>\n", cgiScriptName, reverse ? "" : "r", query_string);
     o("\t</tr>\n");
 }
 void output_ticket_table_body(SearchResult* result, List* element_types)
@@ -308,7 +312,7 @@ void list_action()
 
     db_init();
     project = db_get_project();
-    output_header(project, "状態別チケット一覧", "list.js", NAVI_LIST);
+    output_header(project, "状態別チケット一覧", NULL, NAVI_LIST);
     cgiFormStringNoNewlines("message", message, DEFAULT_LENGTH);
     if (strlen(message) > 0) {
         o("<div class=\"complete_message\">"); h(message); o("&nbsp;</div>\n");
@@ -425,7 +429,7 @@ void search_actoin()
     
     db_init();
     project = db_get_project();
-    output_header(project, "チケット検索", "list.js", NAVI_SEARCH);
+    output_header(project, "チケット検索", NULL, NAVI_SEARCH);
     list_alloc(element_types_a, ElementType);
     element_types_a = db_get_element_types_4_list(element_types_a);
     o("<h2>"); h(project->name); o(" - チケット検索</h2>\n");
@@ -437,13 +441,39 @@ void search_actoin()
         char value[DEFAULT_LENGTH];
         Condition* c;
 
-        sprintf(name, "field%d", et->id);
-        cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
-        if (strlen(value) == 0) continue;
-        c = list_new_element(conditions_a);
-        c->element_type_id = et->id;
-        strcpy(c->value, value);
-        list_add(conditions_a, c);
+        switch (et->type) {
+            case ELEM_TYPE_DATE:
+                /* 日付 from */
+                sprintf(name, "field%d_from", et->id);
+                cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+                if (strlen(value) > 0) {
+                    c = list_new_element(conditions_a);
+                    c->element_type_id = et->id;
+                    c->condition_type = CONDITION_TYPE_DATE_FROM;
+                    strcpy(c->value, value);
+                    list_add(conditions_a, c);
+                }
+                /* 日付 to */
+                sprintf(name, "field%d_to", et->id);
+                cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+                if (strlen(value) > 0) {
+                    c = list_new_element(conditions_a);
+                    c->element_type_id = et->id;
+                    c->condition_type = CONDITION_TYPE_DATE_TO;
+                    strcpy(c->value, value);
+                    list_add(conditions_a, c);
+                }
+                break;
+            default:
+                sprintf(name, "field%d", et->id);
+                cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+                if (strlen(value) == 0) continue;
+                c = list_new_element(conditions_a);
+                c->element_type_id = et->id;
+                c->condition_type = CONDITION_TYPE_NORMAL;
+                strcpy(c->value, value);
+                list_add(conditions_a, c);
+        }
     }
     cgiFormStringNoNewlines("q", q, DEFAULT_LENGTH);
     cgiFormStringNoNewlines("sort", sortstr, DEFAULT_LENGTH);
@@ -490,6 +520,7 @@ void search_actoin()
     o("</div>\n");
     o("<div id=\"condition_form\">\n");
     o("<h3>検索条件</h3>\n");
+    o("<div class=\"description\">検索条件を入力して検索ボタンを押してください。</div>\n");
     o("<form action=\"%s/search\" method=\"get\">\n", cgiScriptName);
     o(      "<table summary=\"condition table\">\n");
     foreach (it, element_types_a) {
@@ -502,7 +533,7 @@ void search_actoin()
         o("<tr>\n");
         o("\t<th>"); h(et->name); o("</th>\n");
         o("\t<td>\n"); 
-        output_form_element_4_condition(value, et);
+        output_form_element_4_condition(et);
         o("\t</td>\n");
         o("</tr>\n");
     }
@@ -543,14 +574,18 @@ void search_actoin()
 /**
  * form要素を表示する。
  */
-void output_form_element_4_condition(char* value, ElementType* e_type)
+void output_form_element_4_condition(ElementType* et)
 {
     char id[DEFAULT_LENGTH];
     List* items_a;
     Iterator* it;
+    char name[DEFAULT_LENGTH];
+    char value[DEFAULT_LENGTH];
+    sprintf(name, "field%d", et->id);
+    cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
 
-    sprintf(id, "%d", e_type->id);
-    switch (e_type->type) {
+    sprintf(id, "%d", et->id);
+    switch (et->type) {
         case ELEM_TYPE_TEXT:
         case ELEM_TYPE_TEXTAREA:
         case ELEM_TYPE_CHECKBOX:
@@ -570,7 +605,7 @@ void output_form_element_4_condition(char* value, ElementType* e_type)
             h(id);
             o("\">\n");
             list_alloc(items_a, ListItem);
-            items_a = db_get_list_item(e_type->id, items_a);
+            items_a = db_get_list_item(et->id, items_a);
 
             o("<option value=\"\">&nbsp;</option>");
             foreach (it, items_a) {
@@ -587,12 +622,35 @@ void output_form_element_4_condition(char* value, ElementType* e_type)
             o("</select>\n");
             list_free(items_a);
             break;
+        case ELEM_TYPE_DATE:
+            sprintf(name, "field%d_from", et->id);
+            cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+            o("<input type=\"text\" class=\"date\" id=\"field");
+            h(id);
+            o("\" name=\"field");
+            h(id);
+            o("_from\" value=\"");
+            v(value);
+            o("\" maxlength=\"10\" />\n");
+/*             o("<a class=\"calender\" href=\"#\" title=\"JavaScriptによる入力支援機能です。\">cale</a>"); */
+            o("〜\n");
+            sprintf(name, "field%d_to", et->id);
+            cgiFormStringNoNewlines(name, value, DEFAULT_LENGTH);
+            o("<input type=\"text\" class=\"date\" id=\"field");
+            h(id);
+            o("\" name=\"field");
+            h(id);
+            o("_to\" value=\"");
+            v(value);
+            o("\" maxlength=\"10\" />\n");
+/*             o("<a class=\"calender\" href=\"#\" title=\"JavaScriptによる入力支援機能です。\">cale</a>"); */
+            break;
     }
 }
 /**
  * form要素を表示する。
  */
-void output_form_element(List* elements, ElementType* e_type)
+void output_form_element(List* elements, ElementType* et)
 {
     char* value = "";
     List* items_a;
@@ -600,9 +658,9 @@ void output_form_element(List* elements, ElementType* e_type)
     int list_count = 0;
 
     if (elements != NULL) {
-        value = get_element_value(elements, e_type);
+        value = get_element_value(elements, et);
     } else {
-        if (e_type->id == ELEM_ID_SENDER) {
+        if (et->id == ELEM_ID_SENDER) {
             char* user_name = getenv("REMOTE_USER");
             char sender[DEFAULT_LENGTH];
             cgiCookieString("starbug1_sender", sender, DEFAULT_LENGTH);
@@ -613,38 +671,38 @@ void output_form_element(List* elements, ElementType* e_type)
                 /* 投稿者のフィールドは、basic認証が行なわれていればそのユーザ名を表示する。 */
                 value = user_name;
             else 
-                value = e_type->default_value;
+                value = et->default_value;
         } else {
-            value = e_type->default_value;
+            value = et->default_value;
         }
     }
-    switch (e_type->type) {
+    switch (et->type) {
         case ELEM_TYPE_TEXT:
             o("<input type=\"text\" class=\"element\" id=\"field%d\" name=\"field%d\" value=\"",
-                    e_type->id, e_type->id);
+                    et->id, et->id);
             v(value);
             o("\" />\n");
             break;
         case ELEM_TYPE_TEXTAREA:
             o("<textarea id=\"field%d\" name=\"field%d\" rows=\"3\" cols=\"10\">",
-                    e_type->id, e_type->id);
+                    et->id, et->id);
             v(value);
             o("</textarea>\n");
             break;
         case ELEM_TYPE_CHECKBOX:
             o("<input type=\"checkbox\" id=\"field%d\" class=\"checkbox\" name=\"field%d\" value=\"",
-                    e_type->id, e_type->id); 
-            v(e_type->name);
+                    et->id, et->id); 
+            v(et->name);
             o("\" %s />",
                     (strlen(value) || strcmp(value, "0") == 0) ? "checked=\"checked\"" : "");
-            o("<label for=\"field%d\">", e_type->id); h(e_type->name); o("</lable>\n");
+            o("<label for=\"field%d\">", et->id); h(et->name); o("</lable>\n");
             break;
         case ELEM_TYPE_LIST_SINGLE:
             o("<select id=\"field%d\" name=\"field%d\">\n",
-                    e_type->id, e_type->id);
+                    et->id, et->id);
             o("<option value=\"\">&nbsp;</option>\n");
             list_alloc(items_a, ListItem);
-            items_a = db_get_list_item(e_type->id, items_a);
+            items_a = db_get_list_item(et->id, items_a);
             foreach (it, items_a) {
                 ListItem* item = it->element;
                 o("<option value=\"");
@@ -662,11 +720,11 @@ void output_form_element(List* elements, ElementType* e_type)
             break;
         case ELEM_TYPE_LIST_MULTI:
             list_alloc(items_a, ListItem);
-            items_a = db_get_list_item(e_type->id, items_a);
+            items_a = db_get_list_item(et->id, items_a);
             /* リストの要素数をカウントする */
             foreach (it, items_a) list_count++;
-            o("<select size=\"%d\" id=\"field%d", list_count + 1, e_type->id);
-            o("\" name=\"field%d\" multiple=\"multiple\">\n", e_type->id);
+            o("<select size=\"%d\" id=\"field%d", list_count + 1, et->id);
+            o("\" name=\"field%d\" multiple=\"multiple\">\n", et->id);
 
             o("<option value=\"\">&nbsp;</option>\n");
             foreach (it, items_a) {
@@ -686,16 +744,25 @@ void output_form_element(List* elements, ElementType* e_type)
             break;
         case ELEM_TYPE_UPLOADFILE:
             o("<input type=\"file\" class=\"element\" id=\"field%d\" name=\"field%d\" />\n",
-                    e_type->id, e_type->id);
+                    et->id, et->id);
+            o("<div class=\"description\">ファイルサイズは、%dKb以下になるようにしてください。</div>\n", MAX_FILE_SIZE);
+            break;
+        case ELEM_TYPE_DATE:
+            o("<input type=\"text\" class=\"date\" id=\"field%d\" name=\"field%d\" value=\"\n",
+                    et->id, et->id);
+            v(value);
+            o("\" maxlength=\"10\"/>\n");
+/*             o("<a class=\"calender\" href=\"#\" title=\"JavaScriptによる入力支援機能です。\">cale</a>"); */
+            o("<div class=\"description\">yyyy-mm-dd形式で入力してください。</div>\n");
             break;
     }
-    switch (e_type->type) {
+    switch (et->type) {
         case ELEM_TYPE_LIST_SINGLE:
         case ELEM_TYPE_LIST_MULTI:
-            if (e_type->auto_add_item) {
+            if (et->auto_add_item) {
                 /* 新規項目を設定可能である場合、テキストボックスを表示する。 */
                 o("<input type=\"text\" class=\"element_new_item\" id=\"field%d\" name=\"field%d.new_item\" />\n",
-                    e_type->id, e_type->id);
+                    et->id, et->id);
                 o("選択肢を追加する場合はテキストボックスに入力してください。\n");
             }
             break;
@@ -711,6 +778,28 @@ static int contains(char* const value, const char* name)
     } while ((p = strstr(p, "\t")) != NULL);
     return 0;
 }
+void output_field_information_js(List* element_types) {
+    Iterator* it;
+    o("<script type=\"text/javascript\" src=\"%s/../js/validate.js\"></script>\n", cgiScriptName); 
+    o("<script type=\"text/javascript\">\n"); 
+    o("\tvar required_field_indexs = [\n");
+    foreach (it, element_types) {
+        ElementType* et = it->element;
+        if (et->required) {
+            o("\t%d,\n", et->id);
+        }
+    }
+    o("\t-1];\n");
+    o("\tvar date_field_indexs = [\n");
+    foreach (it, element_types) {
+        ElementType* et = it->element;
+        if (et->type == ELEM_TYPE_DATE) {
+            o("\t%d,\n", et->id);
+        }
+    }
+    o("\t-1];\n");
+    o("</script>\n");
+}
 /**
  * 登録画面を表示するaction。
  */
@@ -726,8 +815,8 @@ void register_action()
     o(      "<h2>"); h(project->name);o(" - チケット登録</h2>\n"
             "<div id=\"input_form\">\n"
             "<h3>チケット登録</h3>\n"
-            "<div class=\"description\">新規チケットを登録する場合は、以下のフォームを記入し登録ボタンをクリックしてください。</div>\n"
-            "<div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div>\n");
+            "<div class=\"description\">新規チケットを登録する場合は、以下のフォームを記入し登録ボタンを押してください。</div>\n"
+            "<noscript><div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div></noscript>\n");
     o(      "<form id=\"register_form\" name=\"register_form\" action=\"%s/register_submit\" method=\"post\" enctype=\"multipart/form-data\">\n", cgiScriptName);
     o(      "<table summary=\"input infomation\">\n");
     {
@@ -748,14 +837,17 @@ void register_action()
             o("</th><td>\n");
             if (et->required)
                 o("\t\t\t<div id=\"field%d.required\" class=\"error\"></div>\n", et->id);
+            if (et->type == ELEM_TYPE_DATE)
+                o("\t\t<div id=\"field%d.datefield\" class=\"error\"></div>\n", et->id);
             output_form_element(NULL, et);
             o("\t\t\t<div class=\"description\">");h(et->description);o("&nbsp;</div>\n");
             o("\t\t</td>\n");
             o("\t</tr>\n");
         }
+        o("</table>\n");
+        output_field_information_js(element_types_a);
         list_free(element_types_a);
     }
-    o(      "</table>\n");
     o(      "<input class=\"button\" type=\"submit\" name=\"register\" value=\"登録\" />\n"
             "<input id=\"save2cookie\" type=\"checkbox\" name=\"save2cookie\" class=\"checkbox\" value=\"1\" %s />\n"
             "<label for=\"save2cookie\">投稿者を保存する。(cookie使用)</label>\n"
@@ -808,15 +900,19 @@ void ticket_action()
             "<h3>チケット最新情報</h3>\n"
             "<div class=\"description\">チケットの最新情報です。最新チケットのチケット属性の付いている属性と全添付ファイルを表示しています。</div>\n"
             "<table summary=\"newest table\">\n");
+    o(      "\t<tr>\n");
+    o(      "\t\t<th>ID</th>\n");
+    o(      "\t\t<td>%d</td>\n", iid);
+    o(      "\t</tr>\n");
     foreach (it, element_types_a) {
         ElementType* et = it->element;
         char* value = get_element_value(elements_a, et);
         if (et->ticket_property == 0) continue;
         o("\t<tr>\n");
-        o("\t\t<th>");
+        o("\t\t<th>\n");
         h(et->name);
         o("&nbsp;</th>\n");
-        o("\t\t<td>");
+        o("\t\t<td>\n");
         switch (et->id) {
             case ELEM_ID_SENDER:
                 hmail(value);
@@ -922,8 +1018,8 @@ void ticket_action()
             "<h3>チケット返信</h3>\n");
     o(      "<form id=\"reply_form\" name=\"reply_form\" action=\"%s/register_submit\" method=\"post\" enctype=\"multipart/form-data\">\n", cgiScriptName);
     o(      "<input type=\"hidden\" name=\"ticket_id\" value=\"%s\" />\n", ticket_id);
-    o(      "<div class=\"description\">返信を行なう場合は、以下のフォームに内容を記入して返信ボタンをクリックしてください。</div>\n"
-            "<div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div>\n"
+    o(      "<div class=\"description\">返信を行なう場合は、以下のフォームに内容を記入して返信ボタンを押してください。</div>\n"
+            "<noscript><div class=\"description\">※必須項目の入力チェックは、javascriptで行なっています。</div></noscript>\n"
             "<table summary=\"input table\">\n");
     foreach (it, element_types_a) {
         ElementType* et = it->element;
@@ -939,6 +1035,8 @@ void ticket_action()
         o("</th>\n\t\t<td>");
         if (et->required)
             o("\t\t<div id=\"field%d.required\" class=\"error\"></div>\n", et->id);
+        if (et->type == ELEM_TYPE_DATE)
+            o("\t\t<div id=\"field%d.datefield\" class=\"error\"></div>\n", et->id);
         if (last_elements != NULL) {
             if (et->ticket_property)
                 output_form_element(last_elements, et);
@@ -958,6 +1056,7 @@ void ticket_action()
             "<label for=\"save2cookie\">投稿者を保存する。(cookie使用)</label>\n"
             "</form>\n"
             "</div>\n", strlen(sender) ? "checked" : "");
+    output_field_information_js(element_types_a);
     db_finish();
     output_footer();
     list_free(element_types_a);
@@ -1020,6 +1119,7 @@ void register_submit_action()
             e->is_file = 0;
             switch (et->type) {
                 case ELEM_TYPE_TEXT:
+                case ELEM_TYPE_DATE:
                     cgiFormStringNoNewlines(name, value_a, VALUE_LENGTH);
                     e->str_val = (char*)xalloc(sizeof(char) * strlen(value_a) + 1);
                     strcpy(e->str_val, value_a);
@@ -1089,6 +1189,7 @@ void register_submit_action()
             }
             if (e->element_type_id == ELEM_ID_SENDER) {
                 if (strcmp(save2cookie, "1") == 0) {
+                    d("set cookie: %s, %s, %s\n", e->str_val, cgiScriptName, cgiServerName);
                     cgiHeaderCookieSetString("starbug1_sender", e->str_val, 86400 * 30, cgiScriptName, cgiServerName);
                 } else {
                     cgiHeaderCookieSetString("starbug1_sender", "", 0, cgiScriptName, cgiServerName);
@@ -1180,6 +1281,14 @@ void default_action()
     list_free(states_a);
     o(      "\t</ul>\n");
     o(      "</div>\n");
+    /* ID検索フォームの表示 */
+    o(      "<div id=\"top_id_search\">\n");
+    o(      "<h4>ID検索</h4>\n");
+    o(      "\t<form action=\"%s/search\" method=\"get\">\n", cgiScriptName);
+    o(      "\t\t<input type=\"text\" class=\"number\" name=\"id\" title=\"入力したIDのチケットを表示します。\" />\n");
+    o(      "\t\t<input type=\"submit\" class=\"button\" value=\"表示\" />\n");
+    o(      "\t</form>\n");
+    o(      "</div>\n");
     o(      "</div>\n");
     db_finish();
     o(      "<div id=\"main\">\n");
@@ -1255,6 +1364,55 @@ void rss_action()
     o(      "</rdf:RDF>\n");
     db_finish();
 }
+void statistics_action()
+{
+    Project* project;
+    List* element_types_a;
+    Iterator* it;
+
+    db_init();
+    project = db_get_project();
+    output_header(project, "統計情報", NULL, NAVI_STATISTICS);
+    o(      "<h2>");h(project->name);o(" - Starbug1</h2>\n");
+    o(      "<div id=\"top\">\n");
+    o(      "<h3>統計情報</h3>\n");
+    o(      "\t<div class=\"description\">統計情報を表示します。</div>\n");
+    list_alloc(element_types_a, ElementType);
+    element_types_a = db_get_element_types_all(element_types_a);
+    foreach (it, element_types_a) {
+        ElementType* et = it->element;
+        List* items_a;
+        Iterator* it_item;
+
+        list_alloc(items_a, State);
+        switch (et->type) {
+            case ELEM_TYPE_LIST_SINGLE:
+                items_a = db_get_statictics(items_a, et->id);
+                goto got_item;
+            case ELEM_TYPE_LIST_MULTI:
+                items_a = db_get_statictics_multi(items_a, et->id);
+got_item:
+                o(      "\t<h4 class=\"item\">");
+                h(et->name);
+                o(      "\t</h4>");
+                o(      "\t<ul>\n");
+                foreach (it_item, items_a) {
+                    State* item = it_item->element;
+                    o(      "\t\t<li>\n");
+                    h(item->name);
+                    o(      "(%d)", item->count);
+                    o(      "\t\t</li>\n");
+                }
+                o(      "\t</ul>\n");
+                break;
+        }
+        list_free(items_a);
+    }
+    list_free(element_types_a);
+    o(      "</div>\n");
+    output_footer();
+    db_finish();
+}
 void help_action()
 {
     Project* project;
@@ -1278,7 +1436,7 @@ void edit_top_action()
     o(      "<h2>トップページの編集</h2>\n"
             "<div id=\"top\">\n"
             "<h3>トップページの編集</h3>\n"
-            "<div id=\"description\">簡易wikiの文法でトップページのコンテンツの編集を行ない、更新ボタンをクリックしてください。</div>\n"
+            "<div id=\"description\">簡易wikiの文法でトップページのコンテンツの編集を行ない、更新ボタンを押してください。</div>\n"
             "<form id=\"edit_top_form\" action=\"%s/edit_top_submit\" method=\"post\">\n", cgiScriptName);
     o(      "<textarea name=\"edit_top\" id=\"edit_top\" rows=\"3\" cols=\"10\">");
     wiki_content_out("wiki/top.wiki");
